==> apache-artemis-2.34.0-source-release.tar.gz: apache-artemis-2.34.0/tests/integration-tests/src/test/java/org/apache/activemq/artemis/tests/integration/jms/multiprotocol/JMSClientIDTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.activemq.artemis.tests.integration.jms.multiprotocol;

import org.apache.activemq.artemis.tests.util.RandomUtil;
import org.junit.Test;

public class JMSClientIDTest extends MultiprotocolJMSClientTestSupport {

   @Test
   public void testAMQPJmsClientIdSetOnBroker() throws Exception {
      String testClientId = RandomUtil.randomString();
      createConnection(testClientId);
      assertEquals(testClientId, server.getRemotingService().getConnections().iterator().next().getClientID());
   }

   @Test
   public void testOpenWireJmsClientIdSetOnBroker() throws Exception {
      String testClientId = RandomUtil.randomString();
      createOpenWireConnection(testClientId);
      assertEquals(testClientId, server.getRemotingService().getConnections().iterator().next().getClientID());
   }

   @Test
   public void testCoreJmsClientIdSetOnBroker() throws Exception {
      String testClientId = RandomUtil.randomString();
      createCoreConnection(testClientId);
      assertEquals(testClientId, server.getRemotingService().getConnections().iterator().next().getClientID());
   }
}

==> apache-artemis-2.35.0-source-release.tar.gz: apache-artemis-2.35.0/tests/integration-tests/src/test/java/org/apache/activemq/artemis/tests/integration/jms/multiprotocol/JMSClientIDTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.activemq.artemis.tests.integration.jms.multiprotocol;

import static org.junit.jupiter.api.Assertions.assertEquals;

import org.apache.activemq.artemis.tests.util.RandomUtil;
import org.junit.jupiter.api.Test;

public class JMSClientIDTest extends MultiprotocolJMSClientTestSupport {

   @Test
   public void testAMQPJmsClientIdSetOnBroker() throws Exception {
      String testClientId = RandomUtil.randomString();
      createConnection(testClientId);
      assertEquals(testClientId, server.getRemotingService().getConnections().iterator().next().getClientID());
   }

   @Test
   public void testOpenWireJmsClientIdSetOnBroker() throws Exception {
      String testClientId = RandomUtil.randomString();
      createOpenWireConnection(testClientId);
      assertEquals(testClientId, server.getRemotingService().getConnections().iterator().next().getClientID());
   }

   @Test
   public void testCoreJmsClientIdSetOnBroker() throws Exception {
      String testClientId = RandomUtil.randomString();
      createCoreConnection(testClientId);
      assertEquals(testClientId, server.getRemotingService().getConnections().iterator().next().getClientID());
   }
}
